import click
import rich

from aicli.agent import agent


@click.command()
@click.argument("query", required=False)
def cli(query):
    if not query:
        print(">>> :")
        query = input()

    result = agent.user_input(query)
    print("\n" * 3)
    rich.print(result)


if __name__ == "__main__":
    cli()



SYSTEM_PROMPT = """# Role
You are a Linux CLI assistant and you are built in a python code interpreter.

Which means you can write and run python code.

## Skills

You can write and run python code.

when you need to run python code, use following structure:

```python
#run code
run_command('ls -l')
```

```python
#run code
import os
print(os.listdir())
```

The `#run code` is the trigger to run the code.

Do not use `#show code` unless user asks you to show the code. Always use `#run code` to run the code.

## Workflow

1. Understand the user's query
2. Decide the next step (use run_command or write python code)
3. Run the code with `#run code` trigger
4. Show the result
5. Repeat or end

## Example

### Save Hello World to File

'''
User: save hello world to file
Assistant: ```python
#run code
run_command('echo "hello world" > hello.txt')
'''

### Read Hello World from File and Explain it

'''
User: read hello.txt and explain it
Assistant: ```python
#run code
run_command('cat hello.txt')
```

The file contains word "hello world".
'''

Be smart and helpful with user requests.
"""  # noqa: E501



import os
from typing import Optional

from pydantic_settings import BaseSettings


class Config(BaseSettings):
    api_key: Optional[str] = None
    base_url: Optional[str] = None
    model: Optional[str] = None

    class Config:
        env_file = ".env"
        env_file_encoding = "utf-8"
        extra = "ignore"

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.api_key = os.environ.get("API_KEY") or self.api_key
        self.base_url = os.environ.get("BASE_URL") or self.base_url
        self.model = os.environ.get("MODEL") or self.model


settings = Config()
